==> monaco-vscode-view-common-service-override-16.0.1.tgz: package/vscode/src/vs/workbench/contrib/mergeEditor/browser/mergeEditorAccessibilityHelp.js <==

import { ICodeEditorService } from '@codingame/monaco-vscode-api/vscode/vs/editor/browser/services/codeEditorService.service';
import { localize } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { AccessibleViewType, AccessibleContentProvider, AccessibleViewProviderId } from '@codingame/monaco-vscode-api/vscode/vs/platform/accessibility/browser/accessibleView';
import { ContextKeyEqualsExpr } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey';
import { AccessibilityVerbositySettingId } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/accessibility/browser/accessibilityConfiguration';

class MergeEditorAccessibilityHelpProvider {
    constructor() {
        this.name = 'mergeEditor';
        this.type = AccessibleViewType.Help;
        this.priority = 125;
        this.when = ContextKeyEqualsExpr.create('isMergeEditor', true);
    }
    getProvider(accessor) {
        const codeEditorService = accessor.get(ICodeEditorService);
        const codeEditor = codeEditorService.getActiveCodeEditor() || codeEditorService.getFocusedCodeEditor();
        if (!codeEditor) {
            return;
        }
        const content = [
            ( localize(7714, "You are in a merge editor.")),
            ( localize(
            7715,
            "Navigate between merge conflicts using the commands Go to Next Unhandled Conflict{0} and Go to Previous Unhandled Conflict{1}.",
            '<keybinding:merge.goToNextUnhandledConflict>',
            '<keybinding:merge.goToPreviousUnhandledConflict>'
        )),
            ( localize(
            7716,
            "Run the command Merge Editor: Accept All Changes from the Left{0} and Merge Editor: Accept All Changes from the Right{1}",
            '<keybinding:merge.acceptAllInput1>',
            '<keybinding:merge.acceptAllInput2>'
        )),
        ];
        return ( new AccessibleContentProvider(
            AccessibleViewProviderId.MergeEditor,
            { type: AccessibleViewType.Help },
            () => content.join('\n'),
            () => codeEditor.focus(),
            AccessibilityVerbositySettingId.MergeEditor
        ));
    }
}

export { MergeEditorAccessibilityHelpProvider };

==> monaco-vscode-view-common-service-override-17.1.2.tgz: package/vscode/src/vs/workbench/contrib/mergeEditor/browser/mergeEditorAccessibilityHelp.js <==

import { ICodeEditorService } from '@codingame/monaco-vscode-api/vscode/vs/editor/browser/services/codeEditorService.service';
import { localize } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { AccessibleViewType, AccessibleContentProvider, AccessibleViewProviderId } from '@codingame/monaco-vscode-api/vscode/vs/platform/accessibility/browser/accessibleView';
import { ContextKeyEqualsExpr } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey';
import { AccessibilityVerbositySettingId } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/accessibility/browser/accessibilityConfiguration';

class MergeEditorAccessibilityHelpProvider {
    constructor() {
        this.name = 'mergeEditor';
        this.type = AccessibleViewType.Help;
        this.priority = 125;
        this.when = ContextKeyEqualsExpr.create('isMergeEditor', true);
    }
    getProvider(accessor) {
        const codeEditorService = accessor.get(ICodeEditorService);
        const codeEditor = codeEditorService.getActiveCodeEditor() || codeEditorService.getFocusedCodeEditor();
        if (!codeEditor) {
            return;
        }
        const content = [
            ( localize(7803, "You are in a merge editor.")),
            ( localize(
            7804,
            "Navigate between merge conflicts using the commands Go to Next Unhandled Conflict{0} and Go to Previous Unhandled Conflict{1}.",
            '<keybinding:merge.goToNextUnhandledConflict>',
            '<keybinding:merge.goToPreviousUnhandledConflict>'
        )),
            ( localize(
            7805,
            "Run the command Merge Editor: Accept All Incoming Changes from the Left{0} and Merge Editor: Accept All Current Changes from the Right{1}",
            '<keybinding:merge.acceptAllInput1>',
            '<keybinding:merge.acceptAllInput2>'
        )),
            ( localize(7806, "Complete the Merge{0}.", '<keybinding:mergeEditor.acceptMerge>')),
            ( localize(
            7807,
            "Toggle between merge editor inputs, incoming and current changes {0}.",
            '<keybinding:mergeEditor.toggleBetweenInputs>'
        )),
        ];
        return ( new AccessibleContentProvider(
            AccessibleViewProviderId.MergeEditor,
            { type: AccessibleViewType.Help },
            () => content.join('\n'),
            () => codeEditor.focus(),
            AccessibilityVerbositySettingId.MergeEditor
        ));
    }
}

export { MergeEditorAccessibilityHelpProvider };
